"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PhoneValidator = exports.EmailValidator = exports.NumberFilter = exports.combineValidators = exports.RequiredValidator = void 0;
exports.RequiredValidator = (value) => {
    if (!Boolean(value))
        return new Error("REQUIRED");
};
exports.combineValidators = (...args) => {
    return (arg, store) => {
        for (let validator of args) {
            const result = validator(arg, store);
            if (result instanceof Error) {
                return result;
            }
        }
    };
};
exports.NumberFilter = (arg) => (value) => {
    if (!value && value !== 0)
        return;
    if (arg.gte) {
        if (value <= arg.gte)
            return new Error(`SHOULD_BE_GREATER`);
    }
    if (arg.lte) {
        if (value >= arg.lte)
            return new Error(`SHOULD_BE_LESSER`);
    }
};
exports.EmailValidator = (errorMessage = "NOT_VALID_EMAIL") => (value) => {
    if (!value)
        return;
    if (validate(value))
        return;
    else
        return new Error(errorMessage);
};
exports.PhoneValidator = (errorMessage = "NOT_VALID_PHONE_NUMBER") => (value) => {
    if (!value)
        return;
    if (validatePhone(value))
        return;
    else
        return new Error(errorMessage);
};
const validate = (email) => {
    var re = /^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
    return re.test(email);
};
const validatePhone = (tel) => {
    const regExp = /^[\+]?[(]?[0-9]{3}[)]?[-\s\.]?[0-9]{3}[-\s\.]?[0-9]{4,6}$/im;
    return regExp.test(tel);
};
//# sourceMappingURL=Validators.js.map